Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1135)

Unified Diff: Source/core/layout/LayoutTable.cpp

Issue 1033943002: Rename LayoutStyle to papayawhip (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: ensureComputedStyle Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/layout/LayoutTable.h ('k') | Source/core/layout/LayoutTableCell.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/layout/LayoutTable.cpp
diff --git a/Source/core/layout/LayoutTable.cpp b/Source/core/layout/LayoutTable.cpp
index 0332737bc566d1d39d4eecc54d70499321cc453f..78a4c7f730bab7819da6390bc8de38bb4d14f995 100644
--- a/Source/core/layout/LayoutTable.cpp
+++ b/Source/core/layout/LayoutTable.cpp
@@ -75,7 +75,7 @@ LayoutTable::~LayoutTable()
{
}
-void LayoutTable::styleDidChange(StyleDifference diff, const LayoutStyle* oldStyle)
+void LayoutTable::styleDidChange(StyleDifference diff, const ComputedStyle* oldStyle)
{
LayoutBlock::styleDidChange(diff, oldStyle);
propagateStyleToAnonymousChildren();
@@ -322,7 +322,7 @@ void LayoutTable::updateLogicalWidth()
ASSERT(logicalWidth().toInt() >= minPreferredLogicalWidth().toInt());
}
// This method takes a LayoutStyle's logical width, min-width, or max-width length and computes its actual value.
LayoutUnit LayoutTable::convertStyleLogicalWidthToComputedWidth(const Length& styleLogicalWidth, LayoutUnit availableWidth)
{
if (styleLogicalWidth.isIntrinsic())
@@ -694,7 +694,7 @@ void LayoutTable::computePreferredLogicalWidths()
for (unsigned i = 0; i < m_captions.size(); i++)
m_minPreferredLogicalWidth = std::max(m_minPreferredLogicalWidth, m_captions[i]->minPreferredLogicalWidth());
- const LayoutStyle& styleToUse = styleRef();
+ const ComputedStyle& styleToUse = styleRef();
// FIXME: This should probably be checking for isSpecified since you should be able to use percentage or calc values for min-width.
if (styleToUse.logicalMinWidth().isFixed() && styleToUse.logicalMinWidth().value() > 0) {
m_maxPreferredLogicalWidth = std::max(m_maxPreferredLogicalWidth, adjustContentBoxLogicalWidthForBoxSizing(styleToUse.logicalMinWidth().value()));
@@ -1341,7 +1341,7 @@ bool LayoutTable::nodeAtPoint(const HitTestRequest& request, HitTestResult& resu
LayoutTable* LayoutTable::createAnonymousWithParentRenderer(const LayoutObject* parent)
{
- RefPtr<LayoutStyle> newStyle = LayoutStyle::createAnonymousStyleWithDisplay(parent->styleRef(), TABLE);
+ RefPtr<ComputedStyle> newStyle = ComputedStyle::createAnonymousStyleWithDisplay(parent->styleRef(), TABLE);
LayoutTable* newTable = new LayoutTable(0);
newTable->setDocumentForAnonymous(&parent->document());
newTable->setStyle(newStyle.release());
@@ -322,7 +322,7 @@ void LayoutTable::updateLogicalWidth()
ASSERT(logicalWidth().toInt() >= minPreferredLogicalWidth().toInt());
}
-// This method takes a LayoutStyle's logical width, min-width, or max-width length and computes its actual value.
+// This method takes a ComputedStyle's logical width, min-width, or max-width length and computes its actual value.
LayoutUnit LayoutTable::convertStyleLogicalWidthToComputedWidth(const Length& styleLogicalWidth, LayoutUnit availableWidth)
{
« no previous file with comments | « Source/core/layout/LayoutTable.h ('k') | Source/core/layout/LayoutTableCell.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698